Package: ggiraph
Type: Package
Title: Make 'ggplot2' Graphics Interactive
Description: Create interactive 'ggplot2' graphics using 'htmlwidgets'.
Version: 0.7.9
Authors@R: c(
    person("David", "Gohel", role = c("aut", "cre"),
    email = "david.gohel@ardata.fr"),
    person("Panagiotis", "Skintzos", role = c("aut"),
    email = "sigmapi@posteo.net"),
    person("Mike", "Bostock", role = c("cph"),
    comment = "d3.js"), 
    person("Speros", "Kokenes", role = c("cph"),
    comment = "d3-lasso"), 
    person("Eric", "Shull", role = c("cph"),
    comment = "saveSvgAsPng js library"), 
    person("Eric", "Book", role = c("ctb"),
    comment = "hline and vline geoms")
    )
License: GPL-3
Copyright: See file COPYRIGHTS.
Encoding: UTF-8
SystemRequirements: C++11, libpng
Imports: grid, ggplot2 (>= 3.3.0), htmlwidgets (>= 0.6), stats,
        htmltools, Rcpp (>= 0.12.12), systemfonts, purrr, rlang, uuid
LinkingTo: Rcpp, systemfonts
Suggests: knitr, testthat, rmarkdown, maps, shiny, sf (>= 0.7-3),
        quantreg, xml2 (>= 1.0.0), dplyr
VignetteBuilder: knitr
URL: https://davidgohel.github.io/ggiraph
BugReports: https://github.com/davidgohel/ggiraph/issues
RoxygenNote: 7.1.1
Collate: 'RcppExports.R' 'ipar.R' 'utils_ggplot2_performance.R'
        'utils_ggplot2.R' 'utils.R' 'annotate_interactive.R'
        'annotation_raster_interactive.R' 'dsvg.R' 'dsvg_view.R'
        'element_interactive.R' 'fonts.R' 'geom_abline_interactive.R'
        'geom_path_interactive.R' 'geom_polygon_interactive.R'
        'geom_rect_interactive.R' 'geom_bar_interactive.R'
        'geom_boxplot_interactive.R' 'geom_col_interactive.R'
        'geom_contour_interactive.R' 'geom_crossbar_interactive.R'
        'geom_density_2d_interactive.R' 'geom_density_interactive.R'
        'geom_dotplot_interactive.R' 'geom_errorbar_interactive.R'
        'geom_errorbarh_interactive.R' 'geom_freqpoly_interactive.R'
        'geom_histogram_interactive.R' 'geom_hline_interactive.R'
        'geom_jitter_interactive.R' 'geom_label_interactive.R'
        'geom_linerange_interactive.R' 'geom_map_interactive.R'
        'geom_point_interactive.R' 'geom_pointrange_interactive.R'
        'geom_quantile_interactive.R' 'geom_raster_interactive.R'
        'geom_ribbon_interactive.R' 'geom_segment_interactive.R'
        'geom_sf_interactive.R' 'geom_smooth_interactive.R'
        'geom_text_interactive.R' 'geom_tile_interactive.R'
        'geom_vline_interactive.R' 'ggiraph.R' 'girafe.R'
        'girafe_options.R' 'grob_interactive.R'
        'guide_bins_interactive.R' 'guide_colourbar_interactive.R'
        'guide_coloursteps_interactive.R' 'guide_interactive.R'
        'guide_legend_interactive.R' 'interactive_circle_grob.R'
        'interactive_path_grob.R' 'interactive_points_grob.R'
        'interactive_polygon_grob.R' 'interactive_polyline_grob.R'
        'interactive_raster_grob.R' 'interactive_rect_grob.R'
        'interactive_roundrect_grob.R' 'interactive_segments_grob.R'
        'interactive_text_grob.R' 'labeller_interactive.R'
        'layer_interactive.R' 'scale_alpha_interactive.R'
        'scale_brewer_interactive.R' 'scale_colour_interactive.R'
        'scale_gradient_interactive.R' 'scale_interactive.R'
        'scale_linetype_interactive.R' 'scale_manual_interactive.R'
        'scale_shape_interactive.R' 'scale_size_interactive.R'
        'scale_steps_interactive.R' 'scale_viridis_interactive.R'
        'svg.R' 'tracers.R'
NeedsCompilation: yes
Packaged: 2021-05-11 19:57:23 UTC; davidgohel
Author: David Gohel [aut, cre],
  Panagiotis Skintzos [aut],
  Mike Bostock [cph] (d3.js),
  Speros Kokenes [cph] (d3-lasso),
  Eric Shull [cph] (saveSvgAsPng js library),
  Eric Book [ctb] (hline and vline geoms)
Maintainer: David Gohel <david.gohel@ardata.fr>
Repository: CRAN
Date/Publication: 2021-05-12 06:00:25 UTC
Built: R 4.0.5; x86_64-w64-mingw32; 2021-05-12 10:16:24 UTC; windows
Archs: x64
